unit Toggle;

interface

uses SysUtils, Messages, WinTypes, WinProcs, Classes, Graphics,
  Controls, Forms, StdCtrls, ExtCtrls, Menus, Dialogs;

type

  TToggle = class( TCustomControl )
  protected
    FState : Boolean;
    Bitmap : TBitmap;
    FOnCaption : string;
    FOffCaption : string;
    procedure SetState( Value : Boolean );
    procedure SetOnCaption( Value : string );
    procedure SetOffCaption( Value : string );
    procedure Paint; override;
    procedure Click; override;
    procedure KeyDown( var Key: Word; Shift: TShiftState ); override;
  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
  published
    property State : Boolean read FState write SetStateIV;
    property OnCaption : string read FOnCaption write SetOnCaption;
    property OffCaption : string read FOffCaption write SetOffCaption;
    property Font;
    property TabStop;
    property OnClick;
    property OnDblClick;
    property OnMouseMove;
    property OnMouseDown;
    property OnMouseUp;
    property OnKeyDown;
    property OnKeyUp;
    property OnKeyPress;
    property OnDragOver;
    property OnDragDrop;
    property OnEndDrag;
  end;

procedure Register;

implementation

{$R Toggle.res}

constructor TToggle.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  Bitmap := TBitmap.Create;
  Width := 150;
  TabStop := TRUE;
  Height := 40;
end;

destructor TToggle.Destroy;
begin
   Bitmap.Destroy;
   inherited Destroy;
end;


procedure TToggle.Paint;
var
   Rect : TRect;
   txt : string;
   x, y : integer;
begin
   Rect.Top := 0;
   Rect.Left := 0;
   Rect.Right := Width;
   Rect.Bottom := Height;
   if FState then
    begin
       Bitmap.Handle := LoadBitmap( HInstance, 'INGRON' );
       txt := FOnCaption;
    end
   else
    begin;
       Bitmap.Handle := LoadBitmap( HInstance, 'INGROFF');
       txt := FOffCaption;
    end;
   Canvas.StretchDraw( Rect, Bitmap );
   SetBkMode( Canvas.Handle, TRANSPARENT );
   SetTextAlign( Canvas.Handle, (TA_CENTER or TA_TOP) );
   Canvas.Font := Font;
   x := integer( Width div 2 );
   y := integer( Height div 2 ) - (Canvas.TextHeight('W') div 2);
   Canvas.TextOut( x, y, txt );
end;


procedure TToggle.Click;
begin
   inherited Click;
   SetState( FState );
end;


procedure TToggle.KeyDown( var Key: Word; Shift: TShiftState );
begin
   inherited KeyDown( Key, Shift );
   if Key = 32 then SetState( FState );
end;


procedure TToggle.SetState( Value : Boolean );
begin
   if FState <> Value then
   begin
     FState := not FState;
     Repaint;
   end;
end;


procedure TToggle.SetOnCaption( Value : string );
begin
   FOnCaption := Value;
   Repaint;
end;

procedure TToggle.SetOffCaption( Value : string );
begin
   FOffCaption := Value;
   Repaint;
end;


procedure Register;
begin
  RegisterComponents( 'Samples', [TToggle] );
end;

end.
